@@ -13,10 +13,7 @@
 #' @importFrom futile.logger flog.info
 #' @return No return value, called for side effects
 #' @export
-clean_nowcasts <- function(date = NULL, nowcast_dir = ".") {
-  if (is.null(date)) {
-    date <- Sys.Date()
-  }
+clean_nowcasts <- function(date = Sys.Date(), nowcast_dir = ".") {
   dirs <- list.dirs(nowcast_dir, recursive = FALSE)
   purrr::walk(
     dirs,
@@ -405,6 +402,21 @@ set_dt_single_thread <- function() {
   )
 }
 
+#' Choose a parallel or sequential apply function
+#'
+#' Internal function that chooses an appropriate "apply"-type function (either
+#' [lapply()] or [future.apply::future_lapply()])
+#' @return A function that can be used to apply a function to a list
+#' @keywords internal
+#' @inheritParams stan_opts
+lapply_func <- function(..., backend = "rstan", future.opts = list()) {
+  if (requireNamespace("future.apply", quietly = TRUE) && backend == "rstan") {
+    do.call(future.apply::future_lapply, c(list(...), future.opts))
+  } else {
+    lapply(...)
+  }
+}
+
 #' @importFrom stats glm median na.omit pexp pgamma plnorm quasipoisson rexp
 #' @importFrom stats rlnorm rnorm rpois runif sd var rgamma pnorm
 globalVariables(
@@ -429,6 +441,6 @@ globalVariables(
     "central_lower", "central_upper", "mean_sd", "sd_sd", "average_7_day",
     "..lowers", "..upper_CrI", "..uppers", "timing", "dataset", "last_confirm",
     "report_date", "secondary", "id", "conv", "meanlog", "primary", "scaled",
-    "scaling", "sdlog", "lookup", "new_draw", ".draw"
+    "scaling", "sdlog", "lookup", "new_draw", ".draw", "p", "distribution"
   )
 )
